Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type NodeinfoV1alpha1Client ¶
type NodeinfoV1alpha1Client struct {
// contains filtered or unexported fields
}
NodeinfoV1alpha1Client is used to interact with features provided by the nodeinfo.volcano.sh group.
func New ¶
func New(c rest.Interface) *NodeinfoV1alpha1Client
New creates a new NodeinfoV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*NodeinfoV1alpha1Client, error)
NewForConfig creates a new NodeinfoV1alpha1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new NodeinfoV1alpha1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *NodeinfoV1alpha1Client
NewForConfigOrDie creates a new NodeinfoV1alpha1Client for the given config and panics if there is an error in the config.
func (*NodeinfoV1alpha1Client) Numatopologies ¶
func (c *NodeinfoV1alpha1Client) Numatopologies() NumatopologyInterface
func (*NodeinfoV1alpha1Client) RESTClient ¶
func (c *NodeinfoV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type NodeinfoV1alpha1Interface ¶
type NodeinfoV1alpha1Interface interface {
RESTClient() rest.Interface
NumatopologiesGetter
}
type NumatopologiesGetter ¶
type NumatopologiesGetter interface {
Numatopologies() NumatopologyInterface
}
NumatopologiesGetter has a method to return a NumatopologyInterface. A group's client should implement this interface.
type NumatopologyExpansion ¶
type NumatopologyExpansion interface{}
type NumatopologyInterface ¶
type NumatopologyInterface interface {
Create(ctx context.Context, numatopology *v1alpha1.Numatopology, opts v1.CreateOptions) (*v1alpha1.Numatopology, error)
Update(ctx context.Context, numatopology *v1alpha1.Numatopology, opts v1.UpdateOptions) (*v1alpha1.Numatopology, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.Numatopology, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.NumatopologyList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.Numatopology, err error)
Apply(ctx context.Context, numatopology *nodeinfov1alpha1.NumatopologyApplyConfiguration, opts v1.ApplyOptions) (result *v1alpha1.Numatopology, err error)
NumatopologyExpansion
}
NumatopologyInterface has methods to work with Numatopology resources.