Documentation
¶
Overview ¶
Package fake has the automatically generated clients.
Index ¶
- type FakeHyperNodes
- func (c *FakeHyperNodes) Apply(ctx context.Context, hyperNode *topologyv1alpha1.HyperNodeApplyConfiguration, ...) (result *v1alpha1.HyperNode, err error)
- func (c *FakeHyperNodes) ApplyStatus(ctx context.Context, hyperNode *topologyv1alpha1.HyperNodeApplyConfiguration, ...) (result *v1alpha1.HyperNode, err error)
- func (c *FakeHyperNodes) Create(ctx context.Context, hyperNode *v1alpha1.HyperNode, opts v1.CreateOptions) (result *v1alpha1.HyperNode, err error)
- func (c *FakeHyperNodes) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
- func (c *FakeHyperNodes) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
- func (c *FakeHyperNodes) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1alpha1.HyperNode, err error)
- func (c *FakeHyperNodes) List(ctx context.Context, opts v1.ListOptions) (result *v1alpha1.HyperNodeList, err error)
- func (c *FakeHyperNodes) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, ...) (result *v1alpha1.HyperNode, err error)
- func (c *FakeHyperNodes) Update(ctx context.Context, hyperNode *v1alpha1.HyperNode, opts v1.UpdateOptions) (result *v1alpha1.HyperNode, err error)
- func (c *FakeHyperNodes) UpdateStatus(ctx context.Context, hyperNode *v1alpha1.HyperNode, opts v1.UpdateOptions) (result *v1alpha1.HyperNode, err error)
- func (c *FakeHyperNodes) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
- type FakeTopologyV1alpha1
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FakeHyperNodes ¶
type FakeHyperNodes struct {
Fake *FakeTopologyV1alpha1
}
FakeHyperNodes implements HyperNodeInterface
func (*FakeHyperNodes) Apply ¶
func (c *FakeHyperNodes) Apply(ctx context.Context, hyperNode *topologyv1alpha1.HyperNodeApplyConfiguration, opts v1.ApplyOptions) (result *v1alpha1.HyperNode, err error)
Apply takes the given apply declarative configuration, applies it and returns the applied hyperNode.
func (*FakeHyperNodes) ApplyStatus ¶
func (c *FakeHyperNodes) ApplyStatus(ctx context.Context, hyperNode *topologyv1alpha1.HyperNodeApplyConfiguration, opts v1.ApplyOptions) (result *v1alpha1.HyperNode, err error)
ApplyStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
func (*FakeHyperNodes) Create ¶
func (c *FakeHyperNodes) Create(ctx context.Context, hyperNode *v1alpha1.HyperNode, opts v1.CreateOptions) (result *v1alpha1.HyperNode, err error)
Create takes the representation of a hyperNode and creates it. Returns the server's representation of the hyperNode, and an error, if there is any.
func (*FakeHyperNodes) Delete ¶
func (c *FakeHyperNodes) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
Delete takes name of the hyperNode and deletes it. Returns an error if one occurs.
func (*FakeHyperNodes) DeleteCollection ¶
func (c *FakeHyperNodes) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
DeleteCollection deletes a collection of objects.
func (*FakeHyperNodes) Get ¶
func (c *FakeHyperNodes) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1alpha1.HyperNode, err error)
Get takes name of the hyperNode, and returns the corresponding hyperNode object, and an error if there is any.
func (*FakeHyperNodes) List ¶
func (c *FakeHyperNodes) List(ctx context.Context, opts v1.ListOptions) (result *v1alpha1.HyperNodeList, err error)
List takes label and field selectors, and returns the list of HyperNodes that match those selectors.
func (*FakeHyperNodes) Patch ¶
func (c *FakeHyperNodes) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.HyperNode, err error)
Patch applies the patch and returns the patched hyperNode.
func (*FakeHyperNodes) Update ¶
func (c *FakeHyperNodes) Update(ctx context.Context, hyperNode *v1alpha1.HyperNode, opts v1.UpdateOptions) (result *v1alpha1.HyperNode, err error)
Update takes the representation of a hyperNode and updates it. Returns the server's representation of the hyperNode, and an error, if there is any.
func (*FakeHyperNodes) UpdateStatus ¶
func (c *FakeHyperNodes) UpdateStatus(ctx context.Context, hyperNode *v1alpha1.HyperNode, opts v1.UpdateOptions) (result *v1alpha1.HyperNode, err error)
UpdateStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (*FakeHyperNodes) Watch ¶
func (c *FakeHyperNodes) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Watch returns a watch.Interface that watches the requested hyperNodes.
type FakeTopologyV1alpha1 ¶
func (*FakeTopologyV1alpha1) HyperNodes ¶
func (c *FakeTopologyV1alpha1) HyperNodes() v1alpha1.HyperNodeInterface
func (*FakeTopologyV1alpha1) RESTClient ¶
func (c *FakeTopologyV1alpha1) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.