Documentation
¶
Index ¶
- func NewCommandInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredCommandInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type CommandInformer
- type Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCommandInformer ¶
func NewCommandInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewCommandInformer constructs a new informer for Command type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredCommandInformer ¶
func NewFilteredCommandInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredCommandInformer constructs a new informer for Command type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type CommandInformer ¶
type CommandInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.CommandLister
}
CommandInformer provides access to a shared informer and lister for Commands.
type Interface ¶
type Interface interface {
// Commands returns a CommandInformer.
Commands() CommandInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.