Documentation
¶
Index ¶
- func NewFilteredJobFlowInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredJobTemplateInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewJobFlowInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewJobTemplateInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type Interface
- type JobFlowInformer
- type JobTemplateInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFilteredJobFlowInformer ¶
func NewFilteredJobFlowInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredJobFlowInformer constructs a new informer for JobFlow type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredJobTemplateInformer ¶
func NewFilteredJobTemplateInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredJobTemplateInformer constructs a new informer for JobTemplate type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewJobFlowInformer ¶
func NewJobFlowInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewJobFlowInformer constructs a new informer for JobFlow type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewJobTemplateInformer ¶
func NewJobTemplateInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewJobTemplateInformer constructs a new informer for JobTemplate type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type Interface ¶
type Interface interface {
// JobFlows returns a JobFlowInformer.
JobFlows() JobFlowInformer
// JobTemplates returns a JobTemplateInformer.
JobTemplates() JobTemplateInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type JobFlowInformer ¶
type JobFlowInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.JobFlowLister
}
JobFlowInformer provides access to a shared informer and lister for JobFlows.
type JobTemplateInformer ¶
type JobTemplateInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.JobTemplateLister
}
JobTemplateInformer provides access to a shared informer and lister for JobTemplates.