Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CommandLister ¶
type CommandLister interface {
// List lists all Commands in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Command, err error)
// Commands returns an object that can list and get Commands.
Commands(namespace string) CommandNamespaceLister
CommandListerExpansion
}
CommandLister helps list Commands. All objects returned here must be treated as read-only.
func NewCommandLister ¶
func NewCommandLister(indexer cache.Indexer) CommandLister
NewCommandLister returns a new CommandLister.
type CommandListerExpansion ¶
type CommandListerExpansion interface{}
CommandListerExpansion allows custom methods to be added to CommandLister.
type CommandNamespaceLister ¶
type CommandNamespaceLister interface {
// List lists all Commands in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Command, err error)
// Get retrieves the Command from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.Command, error)
CommandNamespaceListerExpansion
}
CommandNamespaceLister helps list and get Commands. All objects returned here must be treated as read-only.
type CommandNamespaceListerExpansion ¶
type CommandNamespaceListerExpansion interface{}
CommandNamespaceListerExpansion allows custom methods to be added to CommandNamespaceLister.
Click to show internal directories.
Click to hide internal directories.